pub struct ServerCommunicationConfigClient {
client: ServerCommunicationConfigClient<UniffiRepositoryBridge<Arc<dyn ServerCommunicationConfigRepository>>, UniffiPlatformApiBridge<Arc<dyn ServerCommunicationConfigPlatformApi>>>,
}Expand description
UniFFI wrapper for ServerCommunicationConfigClient
Fields
client: ServerCommunicationConfigClient<UniffiRepositoryBridge<Arc<dyn ServerCommunicationConfigRepository>>, UniffiPlatformApiBridge<Arc<dyn ServerCommunicationConfigPlatformApi>>>Implementations
Sourceimpl ServerCommunicationConfigClient
impl ServerCommunicationConfigClient
Sourcepub async fn get_config(
&self,
domain: String,
) -> Result<ServerCommunicationConfig>
pub async fn get_config( &self, domain: String, ) -> Result<ServerCommunicationConfig>
Retrieves the server communication configuration for a domain
Sourcepub async fn needs_bootstrap(&self, domain: String) -> bool
pub async fn needs_bootstrap(&self, domain: String) -> bool
Determines if cookie bootstrapping is needed for this domain
Returns all cookies that should be included in requests to this server
Sourcepub async fn set_communication_type(
&self,
domain: String,
request: SetCommunicationTypeRequest,
) -> Result<()>
👎Deprecated: Use set_communication_type_v2() instead, which extracts the domain from the config
pub async fn set_communication_type( &self, domain: String, request: SetCommunicationTypeRequest, ) -> Result<()>
Sets the server communication configuration for a domain
This method saves the provided communication configuration to the repository.
Typically called when receiving the /api/config response from the server.
Previously acquired cookies are preserved automatically.
Sourcepub async fn set_communication_type_v2(
&self,
request: SetCommunicationTypeRequest,
) -> Result<()>
pub async fn set_communication_type_v2( &self, request: SetCommunicationTypeRequest, ) -> Result<()>
Sets the server communication configuration using the domain from the config
Extracts the cookie_domain from the SsoCookieVendor config and uses it as the
storage key. If the config is Direct or cookie_domain is not set, the call
is silently ignored.
Acquires a cookie from the platform and saves it to the repository